#!/usr/bin/env python
# coding: utf-8

import matplotlib
matplotlib.use('Agg')
from mpl_toolkits.axes_grid1.inset_locator import inset_axes
from matplotlib import pyplot

from gwpy.timeseries import TimeSeries
from gwpy.segments import Segment
from gwpy.plot import Plot
from gwpy.time import tconvert
from astropy.time import Time
from pycbc import frame

import pylab

matplotlib.rcParams['text.usetex'] = True
matplotlib.rcParams['axes.labelsize'] = 9
matplotlib.rcParams['legend.fontsize'] = 9
matplotlib.rcParams['xtick.labelsize'] = 9
matplotlib.rcParams['ytick.labelsize'] = 9
matplotlib.rcParams['font.size'] = 9
matplotlib.rcParams['savefig.dpi'] = 300
matplotlib.rcParams['text.latex.preamble'] = [r'\usepackage{amsmath}',r'\mathchardef\mhyphen="2D']
matplotlib.rcParams['legend.fontsize'] = 9


# labels for each subplot
label = {
    'L1': r"$\mathrm{LIGO\ Livingston}$",
    'V1': r"$\mathrm{Virgo}$",
}

# location of data if not reading from local frame
source = {  # (channel, frametype)
    'L1': ('L1:DCS-CALIB_STRAIN_CLEAN_C01_T1700406_v4'),
    'V1': ('V1:Hrec_hoft_16384Hz')
}

framestore = {
    'L1':'GW200105_162426_L1_deglitched_data.gwf',
    'V1':'GW200105_162426_V1_data.gwf',
}


# -- setup and data access ----------------------------------------------------

# define times
start = 1262276623
end = 1262276686
eventtime = 1262276684.0572
epoch = 1262276684


# plotting parameters
xlim = (-5, 1)
ylim = (10, 1000)
elim = (0, 10)
alim = (0, 15)
dx = 2.0  # tick-step for time axis
dxm = 0.5

# get data
ifos = ['L1', 'V1']

output_plot = 'GW200105-spectrogram'

data = TimeSeries.DictClass()
for ifo in ifos:
    data[ifo] = TimeSeries.read(framestore[ifo],
                                channel=source[ifo],
                                start=start, end=end).astype('float64')
    print('reading from saved .gwf file for %s'%ifo)


print('Done read data')

q_trans = {}
fixed_q = None
qrange = (40,60)
for i in ifos:
    data[i].t0 -= epoch * data[ifo].t0.unit
    q_trans[i] =  data[i].q_transform(qrange=qrange,
                                 outseg=Segment(xlim[0], xlim[1]))
    if not fixed_q:
        fixed_q = q_trans[i].q
        print ('using a Q value of %.2f'%fixed_q)
        qrange = (fixed_q,fixed_q)

plot, axes = pyplot.subplots(nrows=len(data), sharex=True, figsize=(3.375,3.375*1))
for i, ax in zip(ifos,axes):
    pcm = ax.imshow(q_trans[i],vmin=0,vmax=15)
    ax.set_xlim(xlim[0],xlim[1])
    ax.set_ylim(ylim[0],ylim[1])
    ax.set_xlabel('')
    ax.set_yscale('log')
    ax.plot([-100], label=label[i], visible=False)
    ax.grid(alpha=0.6)
    ax.legend(loc='upper left', handlelength=0, handletextpad=0)
    k = ax.get_yticks().tolist()
    k[1]='$10$'
    k[2]='$100$'
    k[3]='$10^3$'
    ax.set_yticklabels(k)

axes[0].set_ylabel(r"$\mathrm{Frequency \ (Hz)}$")
axes[0].set_title(r"$\mathrm{GW200105}$", y=1.7)
cbar = axes[0].colorbar(clim=(0, 15),location='top',ticks=[0,2,4,6,8,10,12,14])
cbar.set_label(r"$\mathrm{Normalized \ energy}$")

iso = Time(epoch, format='gps', scale='utc').iso
utc = iso.rstrip('0').rstrip('.')
utc_latex = utc.replace(" ","\ ").replace(":","{:}").replace("-","\mhyphen ")
axes[-1].set_xlabel(r"$\mathrm{Time \ (seconds)}$")

plot.subplots_adjust(top=0.80)
for ext in ('pdf','png'):
    print('Saving %s' % ext.upper())
    pyplot.savefig('%s.%s' % (output_plot,ext),bbox_inches='tight')
